unit Unit1;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, VclTee.TeeGDIPlus, VCLTee.TeEngine,
  VCLTee.Series, Vcl.ExtCtrls, VCLTee.TeeProcs, VCLTee.Chart;

type
  TForm1 = class(TForm)
    Chart1: TChart;
    Image1: TImage;
    Series1: THorizBarSeries;
  private
    { Private declarations }
    procedure UpdateImage;
  protected
    procedure Resize; override;
  public
    { Public declarations }
    constructor Create(aOwner: TComponent); override;
  end;

var
  Form1: TForm1;

implementation

uses
  VCLTee.TeCanvas;

{$R *.dfm}

procedure AssignChartToGraphic(aChart: TChart; const aRect: TRect; aGraphic: TGraphic; aTransparent: boolean = false);
var
//  {$ifdef Debug}
//  lFileName: string;
//  lPNG: TPNGExportFormat;
//  lEMF: TEMFExportFormat;
//  lFS: TFileStream;
//  {$endif}  // Debug
  lHoldShadow: boolean;
  I: Integer;
  lBoolArray: array of boolean;
  lHoldBevel: TBevelCut;
  lHoldColor: TColor;
  lHoldGradientVisible: boolean;
  lMetafile: TMetafile;
  {$ifopt C+}
  lCanvasClassName: string;
  {$endif}
  lBmp: TBitmap;
begin
  {$ifopt C+}
  lCanvasClassName := aChart.Canvas.ClassName;
  {$endif}
  Assert(aChart.Canvas is TGDIPlusCanvas);
  aChart.Canvas := TTeeCanvas3D.Create;

  lHoldGradientVisible := aChart.Gradient.Visible;
  lHoldColor := aChart.Color;
  lHoldBevel := aChart.BevelOuter;
  lHoldShadow := aChart.Shadow.Visible;

  try
    SetLength(lBoolArray, aChart.SeriesCount);
    for I := 0 to aChart.SeriesCount - 1 do    // Iterate
      if aChart.Series[I] is TPieSeries then
      begin
        lBoolArray[I] := TPieSeries(aChart.Series[I]).Circled;
        TPieSeries(aChart.Series[I]).Circled := True;
      end
      else
        lBoolArray[I] := True;


    aChart.Gradient.Visible  := false;
    if not aTransparent then
      aChart.Color := clWhite
    else
      aChart.Color := clNone; //clWhite;
    aChart.BevelOuter := bvNone;
    aChart.BevelInner := bvNone;
    aChart.Shadow.Visible := False;

    if aGraphic is TMetafile then
    begin
      {$ifdef Debug}
      lMetafile := aChart.TeeCreateMetafile(True, aRect);
      {$else}
      lMetafile := aChart.TeeCreateMetafile(false, aRect);
      {$endif}
      try
        aGraphic.Assign(lMetafile);
//        {$ifdef CodeSite}
//        if CSLogging then
//          CodeSite.Send('Chart Metafile', lMetafile);
//        {$endif}
      finally
        lMetafile.Free;
      end;
    end
    else
    begin
      lBmp := aChart.TeeCreateBitmap(clWhite, aRect);
      try
        aGraphic.Assign(lBmp);
//        {$ifdef CodeSite}
//        if CSLogging then
//          CodeSite.Send('Chart Bitmap', lBmp);
//        {$endif}
      finally
        lBmp.Free;
      end;
    end;
  finally
    aChart.Shadow.Visible := lHoldShadow;
    aChart.Gradient.Visible := lHoldGradientVisible;
    aChart.Color := lHoldColor;
    aChart.BevelOuter := lHoldBevel;
    for I := 0 to aChart.SeriesCount - 1 do    // Iterate
      if aChart.Series[I] is TPieSeries then
        TPieSeries(aChart.Series[I]).Circled := lBoolArray[I];
    aChart.Canvas := TGDIPlusCanvas.Create;
  end;

  {$ifopt C+}
  assert(SameText(lCanvasClassName, aChart.Canvas.ClassName),
    Format('Chart canvas should be %s but is %s', [lCanvasClassName, aChart.Canvas.ClassName]));
  {$endif}
end;


{ TForm1 }

constructor TForm1.Create(aOwner: TComponent);
begin
  inherited;
  Series1.FillSampleValues(20);
end;

procedure TForm1.Resize;
begin
  inherited;
  UpdateImage;
end;

procedure TForm1.UpdateImage;
begin
  Image1.Picture.Graphic := TBitmap.Create;
  AssignChartToGraphic(Chart1, Image1.BoundsRect, Image1.Picture.Graphic);
end;

end.
